@@ -1,5 +1,6 @@
 from __future__ import annotations
 from collections.abc import Callable, Generator
+from warnings import warn
 import contextlib
 import copy
 import json
@@ -364,7 +365,7 @@ class Resource:
         yaml_file: str = "",
         delete_timeout: int = TIMEOUT_4MINUTES,
         dry_run: bool = False,
-        node_selector: str = "",
+        node_selector: Dict[str, Any] | None = None,
         node_selector_labels: Dict[str, str] | None = None,
         config_file: str = "",
         config_dict: Dict[str, Any] | None = None,
@@ -461,9 +462,19 @@ class Resource:
 
     def _prepare_node_selector_spec(self) -> Dict[str, str]:
         if self.node_selector:
-            return {f"{self.ApiGroup.KUBERNETES_IO}/hostname": self.node_selector}
+            if isinstance(self.node_selector, dict):
+                return self.node_selector
+            else:
+                warn(
+                    "node_selector `str` will be deprecated in next release (4.17), pass `dict` instead",
+                    DeprecationWarning,
+                    stacklevel=2,
+                )
+                return {f"{self.ApiGroup.KUBERNETES_IO}/hostname": self.node_selector}
+
         elif self.node_selector_labels:
             return self.node_selector_labels
+
         else:
             return {}
 
@@ -679,7 +690,7 @@ class Resource:
             if sample:
                 return
 
-    def wait_deleted(self, timeout: int = TIMEOUT_4MINUTES) -> None:
+    def wait_deleted(self, timeout: int = TIMEOUT_4MINUTES) -> bool:
         """
         Wait until resource is deleted
 
@@ -706,7 +717,7 @@ class Resource:
     def _kube_v1_api(self) -> kubernetes.client.CoreV1Api:
         return kubernetes.client.CoreV1Api(api_client=self.client.client)
 
-    def client_wait_deleted(self, timeout: int) -> None:
+    def client_wait_deleted(self, timeout: int) -> bool:
         """
         client-side Wait until resource is deleted
 
@@ -719,7 +730,8 @@ class Resource:
         samples = TimeoutSampler(wait_timeout=timeout, sleep=1, func=lambda: self.exists)
         for sample in samples:
             if not sample:
-                return
+                return True
+        return False
 
     def wait_for_status(
         self, status: str, timeout: int = TIMEOUT_4MINUTES, stop_status: str | None = None, sleep: int = 1
@@ -807,18 +819,20 @@ class Resource:
         self.logger.info(f"Delete {self.kind} {self.name}")
 
         if self.exists:
-            hashed_data = self.hash_resource_dict(resource_dict=self.instance.to_dict())
-            self.logger.info(f"Deleting {hashed_data}")
-            self.logger.debug(f"\n{yaml.dump(hashed_data)}")
+            try:
+                hashed_data = self.hash_resource_dict(resource_dict=self.instance.to_dict())
+                self.logger.info(f"Deleting {hashed_data}")
+                self.logger.debug(f"\n{yaml.dump(hashed_data)}")
 
-        try:
-            self.api.delete(name=self.name, namespace=self.namespace, body=body)
-            if wait:
-                self.client_wait_deleted(timeout=timeout)
+                self.api.delete(name=self.name, namespace=self.namespace, body=body)
+                if wait:
+                    return self.wait_deleted(timeout=timeout)
+                return True
 
-        except (NotFoundError, TimeoutExpiredError):
-            return False
+            except (NotFoundError, TimeoutExpiredError):
+                return False
 
+        self.logger.warning(f"Resource {self.kind} {self.name} was not found, and wasn't deleted")
         return True
 
     @property
