@@ -39,7 +39,7 @@ class VirtualMachineRestore(NamespacedResource):
         self.vm_name = vm_name
         self.snapshot_name = snapshot_name
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             spec = self.res.setdefault("spec", {})
